'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _util = require('./util');

var _ajax = require('@fdaciuk/ajax');

var _ajax2 = _interopRequireDefault(_ajax);

require('./style');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var SvgPlayer = function () {
  function SvgPlayer(selector, url, opts, ready) {
    var _this = this;

    _classCallCheck(this, SvgPlayer);

    this._togglePlay = function () {
      // 判断动画是否暂停
      if (_this.getAnimationState()) {
        _this.pause();
      } else {
        _this.play();
      }
    };

    this.play = function () {
      var prefix = _this.opts.prefix;

      _this.svgEl.unpauseAnimations();
      if (_this.playButtonEL) {
        _this.playButtonEL.setAttribute('class', prefix + '-play-btn pause');
      }
    };

    this.pause = function () {
      var prefix = _this.opts.prefix;

      _this.svgEl.pauseAnimations();
      if (_this.playButtonEL) {
        _this.playButtonEL.setAttribute('class', prefix + '-play-btn');
      }
    };

    this._handleWheel = function (e) {
      e.preventDefault();
      var out = e.deltaY ? e.deltaY < 0 : e.wheelDelta > 0;
      _this.handleZoom(out);
    };

    this.handleZoom = function () {
      var out = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
      var _opts = _this.opts,
          zoomStep = _opts.zoomStep,
          minZoomSize = _opts.minZoomSize,
          maxZoomSize = _opts.maxZoomSize;

      var rectSvgEl = _this.svgEl.getBoundingClientRect();
      var ratio = rectSvgEl.width / _this.boxElWidth;
      _this.ratio = (0, _util.getZoomRatio)(ratio, { zoomStep: zoomStep, minZoomSize: minZoomSize, maxZoomSize: maxZoomSize }, out);
      if (ratio > minZoomSize && out || ratio < maxZoomSize && !out) {
        _this.zoomInOut(_this.ratio);
      }
    };

    this.zoomInOut = function (ratio) {
      _this.svgEl.style.transform = 'translateX(' + _this.translateX + 'px) translateY(' + _this.translateY + 'px) scale(' + _this.ratio + ')';
      _this.ratio = ratio;
    };

    this._handleMoveStart = function (e) {
      e.preventDefault();
      if (e.button !== 0) {
        return;
      }
      _this.point = [e.pageX, e.pageY];
    };

    this._handleMove = function (e) {
      e.preventDefault();
      if (!_this.point) {
        return;
      }
      var xDelta = e.pageX - _this.point[0];
      var yDelta = e.pageY - _this.point[1];
      _this.point = [e.pageX, e.pageY];

      var _getComputedTranslate = (0, _util.getComputedTranslateXY)(_this.svgEl),
          _getComputedTranslate2 = _slicedToArray(_getComputedTranslate, 2),
          _getComputedTranslate3 = _getComputedTranslate2[0],
          x = _getComputedTranslate3 === undefined ? 0 : _getComputedTranslate3,
          _getComputedTranslate4 = _getComputedTranslate2[1],
          y = _getComputedTranslate4 === undefined ? 0 : _getComputedTranslate4;

      _this.translateX = x + xDelta;
      _this.translateY = y + yDelta;
      _this.svgEl.style.transform = 'translateX(' + _this.translateX + 'px) translateY(' + _this.translateY + 'px) scale(' + _this.ratio + ')';
    };

    this._handleMoveEnd = function () {
      _this.point = null;
    };

    this.opts = (0, _util.mergeOptions)({
      prefix: 'svg-player',
      style: null,
      attr: null,
      showPlayButton: true,
      showReloadButton: true,
      showZoomButton: false,
      draggable: false,
      scalable: false,
      ratio: 1,
      maxZoomSize: 4,
      minZoomSize: 0.2,
      zoomStep: 0.2
    }, opts);
    this.ratio = this.opts.ratio;
    this.translateX = 0;
    this.translateY = 0;
    this.selector = selector;
    this.ready = ready;
    this.url = url || '';
    this._render();
    this._init();
  }

  _createClass(SvgPlayer, [{
    key: '_render',
    value: function _render() {
      var _this2 = this;

      var prefix = this.opts.prefix;
      this.svgPlayerEl = document.createElement('div');
      this.svgPlayerEl.setAttribute('class', '' + prefix);

      this.svgPlayerToolbarEl = document.createElement('div');
      this.svgPlayerToolbarEl.setAttribute('class', prefix + '-toolbar');

      if (this.opts.style) {
        (0, _util.setStyles)(this.svgPlayerEl, this.opts.style);
      }
      if (this.opts.attr) {
        Object.keys(this.opts.attr).forEach(function (value) {
          _this2.svgPlayerEl.setAttribute(value, _this2.opts.attr[value]);
        });
      }

      // loading
      if (this.opts.renderLoading) {
        this.loadingEl = this.opts.renderLoading();
      } else {
        this.loadingEl = document.createElement('span');
        this.loadingEl.setAttribute('class', prefix + '-loading');
        this.loadingEl.innerHTML = 'loading...';
      }

      this.svgPlayerEl.appendChild(this.svgPlayerToolbarEl);
      this.svgPlayerEl.appendChild(this.loadingEl);

      document.querySelector(this.selector).appendChild(this.svgPlayerEl);
    }
    // 播放暂停按钮

  }, {
    key: '_renderPlayButton',
    value: function _renderPlayButton() {
      var prefix = this.opts.prefix;
      // 播放暂停按钮

      this.playButtonEL = document.createElement('button');
      this.playButtonEL.setAttribute('class', prefix + '-play-btn pause');
      this.svgPlayerToolbarEl.appendChild(this.playButtonEL);

      // 播放暂停按钮
      this.playButtonEL.addEventListener('click', this._togglePlay);
    }
    // 缩放按钮

  }, {
    key: '_renderZoomButton',
    value: function _renderZoomButton() {
      var _this3 = this;

      var prefix = this.opts.prefix;
      // 放大按钮

      this.zoomInEL = document.createElement('button');
      this.zoomInEL.setAttribute('class', prefix + '-zoom-in');
      this.svgPlayerToolbarEl.appendChild(this.zoomInEL);
      this.zoomInEL.addEventListener('click', function () {
        _this3.handleZoom(false);
      });
      // 缩小按钮
      this.zoomOutEL = document.createElement('button');
      this.zoomOutEL.setAttribute('class', prefix + '-zoom-out');
      this.svgPlayerToolbarEl.appendChild(this.zoomOutEL);
      this.zoomOutEL.addEventListener('click', function () {
        _this3.handleZoom(true);
      });
    }
    // 回到开始按钮

  }, {
    key: '_renderReloadButton',
    value: function _renderReloadButton() {
      var _this4 = this;

      var prefix = this.opts.prefix;

      // 动画回到开始
      this.reloadButtonEl = document.createElement('button');
      this.reloadButtonEl.setAttribute('class', prefix + '-reload-btn');
      this.svgPlayerToolbarEl.appendChild(this.reloadButtonEl);

      this.reloadButtonEl.addEventListener('click', function () {
        _this4.svgEl.setCurrentTime(0);
      });
    }
  }, {
    key: '_renderLoading',
    value: function _renderLoading() {
      if (this.opts.renderLoading) {
        this.loadingEl = this.opts.renderLoading();
      } else {
        this.loadingEl = document.createElement('span');
        this.loadingEl.setAttribute('class', this.opts.prefix + '-loading');
        this.loadingEl.innerHTML = 'loading...';
      }
    }
  }, {
    key: '_init',
    value: function _init() {
      var _this5 = this;

      // 是否支持svg动画
      var flagSMIL = Boolean(document.createElementNS('http://www.w3.org/2000/svg', 'svg').animationsPaused);
      (0, _ajax2['default'])({
        method: 'get',
        dataType: 'blob',
        url: this.url
      }).then(function (data, xhr) {
        // 移除loading
        _this5.svgPlayerEl.removeChild(_this5.loadingEl);

        var resContentType = xhr.getResponseHeader('Content-Type');
        if (resContentType !== 'image/svg+xml') {
          console.error('请输入svg类型资源');
          return;
        }
        _this5.svgPlayerEl.appendChild((0, _util.strToDom)(data));

        if (!flagSMIL) {
          console.warn('当前浏览器不支持svg动画');
          return;
        }

        _this5.svgEl = _this5.svgPlayerEl.getElementsByTagName('svg')[0];
        _this5.boxElWidth = _this5.svgEl.getBoundingClientRect().width;

        if (_this5.opts.showPlayButton) {
          _this5._renderPlayButton();
        }

        if (_this5.opts.showReloadButton) {
          _this5._renderReloadButton();
        }

        if (_this5.opts.showZoomButton) {
          _this5._renderZoomButton();
        }

        // 初始化缩放比例
        _this5.zoomInOut(_this5.ratio);

        if (_this5.ready) {
          _this5.ready(_this5);
        }

        // 缩放
        if (_this5.opts.scalable) {
          _this5.svgPlayerEl.addEventListener('mousewheel', _this5._handleWheel);
          _this5.svgPlayerEl.addEventListener('wheel', _this5._handleWheel);
        }

        // 拖拽
        if (_this5.opts.draggable) {
          _this5.svgEl.style.cursor = 'pointer';
          _this5.svgPlayerEl.addEventListener('mousedown', _this5._handleMoveStart);
          _this5.svgPlayerEl.addEventListener('mousemove', _this5._handleMove);
          _this5.svgPlayerEl.addEventListener('mouseup', _this5._handleMoveEnd);
          _this5.svgPlayerEl.addEventListener('mouseleave', _this5._handleMoveEnd);
        }
      });
    }
    // 切换播放暂停

  }, {
    key: 'getAnimationState',
    value: function getAnimationState() {
      return !this.svgEl.animationsPaused();
    }
    // 鼠标滚轮

  }]);

  return SvgPlayer;
}();

global.SvgPlayer = SvgPlayer;
exports['default'] = SvgPlayer;
module.exports = exports['default'];