'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.each = each;
exports.isPlain = isPlain;
exports.isObject = isObject;
exports.getZoomRatio = getZoomRatio;
exports.getComputedTranslateXY = getComputedTranslateXY;
exports.mergeOptions = mergeOptions;
exports.strToDom = strToDom;
exports.divide = divide;
exports.multiple = multiple;
var reUnit = /width|height|top|left|right|bottom|margin|padding/i;

var ZOOM_STEP = 0.2,
    MAX_ZOOM_SIZE = 4,
    MIN_ZOOM_SIZE = 0.2;
exports.ZOOM_STEP = ZOOM_STEP;
exports.MAX_ZOOM_SIZE = MAX_ZOOM_SIZE;
exports.MIN_ZOOM_SIZE = MIN_ZOOM_SIZE;
var keys = exports.keys = function keys(object) {
  return isObject(object) ? Object.keys(object) : [];
};

function each(object, fn) {
  keys(object).forEach(function (key) {
    return fn(object[key], key);
  });
}

function isPlain(value) {
  return isObject(value) && Object.prototype.toString.call(value) === '[object Object]' && value.constructor === Object;
}
function isObject(value) {
  return !!value && (typeof value === 'undefined' ? 'undefined' : _typeof(value)) === 'object';
}

function getZoomRatio(v, _ref) {
  var zoomStep = _ref.zoomStep,
      minZoomSize = _ref.minZoomSize,
      maxZoomSize = _ref.maxZoomSize;
  var out = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  var n = parseInt(divide(v, zoomStep), 10);
  if (out) {
    // 缩小
    return Math.max(minZoomSize, (n - 1) * zoomStep);
  } else {
    // 放大
    return Math.min(maxZoomSize, multiple(n + 1, zoomStep));
  }
}
function getComputedTranslateXY(obj) {
  var transArr = [];
  if (!window.getComputedStyle) {
    return;
  }
  var style = getComputedStyle(obj);
  var transform = style.transform || style.webkitTransform || style.mozTransform;
  var mat = transform.match(/^matrix3d\((.+)\)$/);
  if (mat) {
    return parseFloat(mat[1].split(', ')[13]);
  }
  mat = transform.match(/^matrix\((.+)\)$/);
  mat && transArr.push(parseFloat(mat[1].split(', ')[4]));
  mat && transArr.push(parseFloat(mat[1].split(', ')[5]));
  return transArr;
}
function mergeOptions() {
  var result = {};

  for (var _len = arguments.length, sources = Array(_len), _key = 0; _key < _len; _key++) {
    sources[_key] = arguments[_key];
  }

  sources.forEach(function (source) {
    if (!source) {
      return;
    }

    each(source, function (value, key) {
      if (!isPlain(value)) {
        result[key] = value;
        return;
      }

      if (!isPlain(result[key])) {
        result[key] = {};
      }

      result[key] = mergeOptions(result[key], value);
    });
  });

  return result;
}

function strToDom(str) {
  var objE = document.createElement('div');
  objE.innerHTML = str;
  return objE.children[0];
}

var setStyle = exports.setStyle = function setStyle(node, att, val, style) {
  style = style || node.style;

  if (style) {
    if (val === null || val === '') {
      // normalize unsetting
      val = '';
    } else if (!isNaN(Number(val)) && reUnit.test(att)) {
      // number values may need a unit
      val += 'px';
    }

    if (att === '') {
      att = 'cssText';
      val = '';
    }

    style[att] = val;
  }
};

var setStyles = exports.setStyles = function setStyles(el, hash) {
  var HAS_CSSTEXT_FEATURE = typeof el.style.cssText !== 'undefined';
  function trim(str) {
    return str.replace(/^\s+|\s+$/g, '');
  }
  var originStyleText = void 0;
  var originStyleObj = {};
  if (HAS_CSSTEXT_FEATURE) {
    originStyleText = el.style.cssText;
  } else {
    originStyleText = el.getAttribute('style');
  }
  originStyleText.split(';').forEach(function (item) {
    if (item.indexOf(':') !== -1) {
      var obj = item.split(':');
      originStyleObj[trim(obj[0])] = trim(obj[1]);
    }
  });

  var styleObj = {};
  Object.keys(hash).forEach(function (item) {
    setStyle(el, item, hash[item], styleObj);
  });
  var mergedStyleObj = Object.assign({}, originStyleObj, styleObj);
  var styleText = Object.keys(mergedStyleObj).map(function (item) {
    return item + ': ' + mergedStyleObj[item] + ';';
  }).join(' ');

  if (HAS_CSSTEXT_FEATURE) {
    el.style.cssText = styleText;
  } else {
    el.setAttribute('style', styleText);
  }
};

// 浮点计算精度问题
function divide(a, b) {
  var aInt = 0;
  var bInt = 0;
  try {
    aInt = a.toString().split('.')[1].length;
  } catch (g) {}
  try {
    bInt = b.toString().split('.')[1].length;
  } catch (err) {}
  var aStr = Number(a.toString().replace('.', ''));
  var bStr = Number(b.toString().replace('.', ''));
  return multiple(aStr / bStr, Math.pow(10, bInt - aInt));
}

function multiple(a, b) {
  var aInt = 0;
  var aStr = a.toString();
  var bStr = b.toString();
  try {
    aInt += aStr.split('.')[1].length;
  } catch (f) {}
  try {
    aInt += bStr.split('.')[1].length;
  } catch (f) {}
  return Number(aStr.replace('.', '')) * Number(bStr.replace('.', '')) / Math.pow(10, aInt);
}